<?php

use MediaWiki\MediaWikiServices;

class SpecialViewByLanguage extends SpecialPage {

	public function __construct() {
		parent::__construct( 'ViewByLanguage', 'spelladmin' );
	}

	public function execute( $sub ) {
		if ( !$this->userCanExecute( $this->getUser() ) ) {
			$this->displayRestrictionError();
			return;
		}
		$out = $this->getOutput();
		$out->addModules( 'ext.SpellingDictionary.viewByLanguage' );
		$out->setPageTitle( $this->msg( 'title-view-by-language' ) );
		$out->addWikiMsg( 'view-by-lang-intro' );

		// Building a language selector
		// Display languages in their native name
		if ( method_exists( MediaWikiServices::class, 'getLanguageNameUtils' ) ) {
			// MW 1.34+
			$languages = MediaWikiServices::getInstance()->getLanguageNameUtils()
				->getLanguageNames(
					MediaWiki\Languages\LanguageNameUtils::AUTONYMS,
					MediaWiki\Languages\LanguageNameUtils::SUPPORTED
				);
		} else {
			$languages = Language::fetchLanguageNames( null, 'mwfile' );
		}
		ksort( $languages );
		$options = [];
		foreach ( $languages as $code => $name ) {
			$options["$code - $name"] = $code;
		}

		$formDescriptor = [
			'language' => [
				'type' => 'select',
				'label-message' => 'sd-admin-select-language',
				'required' => true,
				'options' => $options,
				'section' => 'section-chooselanguage',
			]
		];
		$form = HTMLForm::factory( 'ooui', $formDescriptor, $this->getContext() );
		$form->setId( 'languageSelectionForm' );
		$form->setMessagePrefix( 'view-by-lang' );
		$form->setSubmitText( wfMessage( 'sd-admin-view-selected-language' )->text() );
		// Callback function
		$form->setSubmitCallback( [ $this, 'showSpellings' ] );
		$form->show();
	}

	public function showSpellings( $formData ) {
		$language = $formData['language'];
		$out = $this->getOutput();
		$out->addHTML( AdminRights::displayByLanguage( $language ) );
	}

	protected function getGroupName() {
		return 'other';
	}
}
